/**
 * Copyright (c) 2017-2018 INCHRON GmbH
 * 
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     INCHRON GmbH - Meta Model design and implementation
 */
package com.inchron.realtime.root.model.impl;

import com.inchron.realtime.root.model.Clock;
import com.inchron.realtime.root.model.Connection;
import com.inchron.realtime.root.model.Cpu;
import com.inchron.realtime.root.model.Event;
import com.inchron.realtime.root.model.EventChain;
import com.inchron.realtime.root.model.GeneralInfo;
import com.inchron.realtime.root.model.ModeCondition;
import com.inchron.realtime.root.model.ModeGroup;
import com.inchron.realtime.root.model.Model;
import com.inchron.realtime.root.model.ModelPackage;
import com.inchron.realtime.root.model.TraceEvent;

import com.inchron.realtime.root.model.fmi.ModelDescription;

import com.inchron.realtime.root.model.memory.Interconnect;
import com.inchron.realtime.root.model.memory.Memory;

import com.inchron.realtime.root.model.peripheral.Bus;
import com.inchron.realtime.root.model.peripheral.PortConnection;

import com.inchron.realtime.root.model.requirement.Requirement;

import com.inchron.realtime.root.model.stimulation.StimulationScenario;

import java.util.Collection;

import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.notify.NotificationChain;

import org.eclipse.emf.common.util.EList;

import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.InternalEObject;

import org.eclipse.emf.ecore.impl.ENotificationImpl;

import org.eclipse.emf.ecore.util.EObjectContainmentEList;
import org.eclipse.emf.ecore.util.InternalEList;

/**
 * <!-- begin-user-doc -->
 * An implementation of the model object '<em><b>Model</b></em>'.
 * <!-- end-user-doc -->
 * <p>
 * The following features are implemented:
 * </p>
 * <ul>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#getBusPeripherals <em>Bus Peripherals</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#getClocks <em>Clocks</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#getCpus <em>Cpus</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#getConnections <em>Connections</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#getEventChains <em>Event Chains</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#getEvents <em>Events</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#getFmi <em>Fmi</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#getGeneralInfo <em>General Info</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#getGlobalModeConditions <em>Global Mode Conditions</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#getGlobalModeGroups <em>Global Mode Groups</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#getInterconnects <em>Interconnects</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#getMemories <em>Memories</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#isOmitCallNestingDiagram <em>Omit Call Nesting Diagram</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#isOmitImplicitEventChains <em>Omit Implicit Event Chains</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#isOmitStackDiagram <em>Omit Stack Diagram</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#getPeripheralPortConnections <em>Peripheral Port Connections</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#getRequirements <em>Requirements</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#getStimulationScenarios <em>Stimulation Scenarios</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#getDefaultScenario <em>Default Scenario</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#getSystems <em>Systems</em>}</li>
 *   <li>{@link com.inchron.realtime.root.model.impl.ModelImpl#getTraceEvents <em>Trace Events</em>}</li>
 * </ul>
 *
 * @generated
 */
public class ModelImpl extends ModelObjectImpl implements Model {
	/**
	 * The cached value of the '{@link #getBusPeripherals() <em>Bus Peripherals</em>}' containment reference list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #getBusPeripherals()
	 * @generated
	 * @ordered
	 */
	protected EList<Bus> busPeripherals;

	/**
	 * The cached value of the '{@link #getClocks() <em>Clocks</em>}' containment reference list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #getClocks()
	 * @generated
	 * @ordered
	 */
	protected EList<Clock> clocks;

	/**
	 * The cached value of the '{@link #getCpus() <em>Cpus</em>}' containment reference list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #getCpus()
	 * @generated
	 * @ordered
	 */
	protected EList<Cpu> cpus;

	/**
	 * The cached value of the '{@link #getConnections() <em>Connections</em>}' containment reference list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #getConnections()
	 * @generated
	 * @ordered
	 */
	protected EList<Connection> connections;

	/**
	 * The cached value of the '{@link #getEventChains() <em>Event Chains</em>}' containment reference list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #getEventChains()
	 * @generated
	 * @ordered
	 */
	protected EList<EventChain> eventChains;

	/**
	 * The cached value of the '{@link #getEvents() <em>Events</em>}' containment reference list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #getEvents()
	 * @generated
	 * @ordered
	 */
	protected EList<Event> events;

	/**
	 * The cached value of the '{@link #getFmi() <em>Fmi</em>}' containment reference.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #getFmi()
	 * @generated
	 * @ordered
	 */
	protected ModelDescription fmi;

	/**
	 * The cached value of the '{@link #getGeneralInfo() <em>General Info</em>}' containment reference.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #getGeneralInfo()
	 * @generated
	 * @ordered
	 */
	protected GeneralInfo generalInfo;

	/**
	 * The cached value of the '{@link #getGlobalModeConditions() <em>Global Mode Conditions</em>}' containment reference list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #getGlobalModeConditions()
	 * @generated
	 * @ordered
	 */
	protected EList<ModeCondition> globalModeConditions;

	/**
	 * The cached value of the '{@link #getGlobalModeGroups() <em>Global Mode Groups</em>}' containment reference list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #getGlobalModeGroups()
	 * @generated
	 * @ordered
	 */
	protected EList<ModeGroup> globalModeGroups;

	/**
	 * The cached value of the '{@link #getInterconnects() <em>Interconnects</em>}' containment reference list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #getInterconnects()
	 * @generated
	 * @ordered
	 */
	protected EList<Interconnect> interconnects;

	/**
	 * The cached value of the '{@link #getMemories() <em>Memories</em>}' containment reference list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #getMemories()
	 * @generated
	 * @ordered
	 */
	protected EList<Memory> memories;

	/**
	 * The default value of the '{@link #isOmitCallNestingDiagram() <em>Omit Call Nesting Diagram</em>}' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #isOmitCallNestingDiagram()
	 * @generated
	 * @ordered
	 */
	protected static final boolean OMIT_CALL_NESTING_DIAGRAM_EDEFAULT = true;

	/**
	 * The cached value of the '{@link #isOmitCallNestingDiagram() <em>Omit Call Nesting Diagram</em>}' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #isOmitCallNestingDiagram()
	 * @generated
	 * @ordered
	 */
	protected boolean omitCallNestingDiagram = OMIT_CALL_NESTING_DIAGRAM_EDEFAULT;

	/**
	 * The default value of the '{@link #isOmitImplicitEventChains() <em>Omit Implicit Event Chains</em>}' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #isOmitImplicitEventChains()
	 * @generated
	 * @ordered
	 */
	protected static final boolean OMIT_IMPLICIT_EVENT_CHAINS_EDEFAULT = true;

	/**
	 * The cached value of the '{@link #isOmitImplicitEventChains() <em>Omit Implicit Event Chains</em>}' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #isOmitImplicitEventChains()
	 * @generated
	 * @ordered
	 */
	protected boolean omitImplicitEventChains = OMIT_IMPLICIT_EVENT_CHAINS_EDEFAULT;

	/**
	 * The default value of the '{@link #isOmitStackDiagram() <em>Omit Stack Diagram</em>}' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #isOmitStackDiagram()
	 * @generated
	 * @ordered
	 */
	protected static final boolean OMIT_STACK_DIAGRAM_EDEFAULT = true;

	/**
	 * The cached value of the '{@link #isOmitStackDiagram() <em>Omit Stack Diagram</em>}' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #isOmitStackDiagram()
	 * @generated
	 * @ordered
	 */
	protected boolean omitStackDiagram = OMIT_STACK_DIAGRAM_EDEFAULT;

	/**
	 * The cached value of the '{@link #getPeripheralPortConnections() <em>Peripheral Port Connections</em>}' containment reference list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #getPeripheralPortConnections()
	 * @generated
	 * @ordered
	 */
	protected EList<PortConnection> peripheralPortConnections;

	/**
	 * The cached value of the '{@link #getRequirements() <em>Requirements</em>}' containment reference list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #getRequirements()
	 * @generated
	 * @ordered
	 */
	protected EList<Requirement> requirements;

	/**
	 * The cached value of the '{@link #getStimulationScenarios() <em>Stimulation Scenarios</em>}' containment reference list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #getStimulationScenarios()
	 * @generated
	 * @ordered
	 */
	protected EList<StimulationScenario> stimulationScenarios;

	/**
	 * The cached value of the '{@link #getDefaultScenario() <em>Default Scenario</em>}' reference.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #getDefaultScenario()
	 * @generated
	 * @ordered
	 */
	protected StimulationScenario defaultScenario;

	/**
	 * The cached value of the '{@link #getSystems() <em>Systems</em>}' containment reference list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #getSystems()
	 * @generated
	 * @ordered
	 */
	protected EList<com.inchron.realtime.root.model.System> systems;

	/**
	 * The cached value of the '{@link #getTraceEvents() <em>Trace Events</em>}' containment reference list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see #getTraceEvents()
	 * @generated
	 * @ordered
	 */
	protected EList<TraceEvent> traceEvents;

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	protected ModelImpl() {
		super();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	@Override
	protected EClass eStaticClass() {
		return ModelPackage.eINSTANCE.getModel();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EList<Bus> getBusPeripherals() {
		if (busPeripherals == null) {
			busPeripherals = new EObjectContainmentEList<Bus>(Bus.class, this, ModelPackage.MODEL__BUS_PERIPHERALS);
		}
		return busPeripherals;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EList<Clock> getClocks() {
		if (clocks == null) {
			clocks = new EObjectContainmentEList<Clock>(Clock.class, this, ModelPackage.MODEL__CLOCKS);
		}
		return clocks;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EList<Cpu> getCpus() {
		if (cpus == null) {
			cpus = new EObjectContainmentEList<Cpu>(Cpu.class, this, ModelPackage.MODEL__CPUS);
		}
		return cpus;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EList<Connection> getConnections() {
		if (connections == null) {
			connections = new EObjectContainmentEList<Connection>(Connection.class, this, ModelPackage.MODEL__CONNECTIONS);
		}
		return connections;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EList<EventChain> getEventChains() {
		if (eventChains == null) {
			eventChains = new EObjectContainmentEList<EventChain>(EventChain.class, this, ModelPackage.MODEL__EVENT_CHAINS);
		}
		return eventChains;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EList<Event> getEvents() {
		if (events == null) {
			events = new EObjectContainmentEList<Event>(Event.class, this, ModelPackage.MODEL__EVENTS);
		}
		return events;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ModelDescription getFmi() {
		return fmi;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public NotificationChain basicSetFmi(ModelDescription newFmi, NotificationChain msgs) {
		ModelDescription oldFmi = fmi;
		fmi = newFmi;
		if (eNotificationRequired()) {
			ENotificationImpl notification = new ENotificationImpl(this, Notification.SET, ModelPackage.MODEL__FMI, oldFmi, newFmi);
			if (msgs == null) msgs = notification; else msgs.add(notification);
		}
		return msgs;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public void setFmi(ModelDescription newFmi) {
		if (newFmi != fmi) {
			NotificationChain msgs = null;
			if (fmi != null)
				msgs = ((InternalEObject)fmi).eInverseRemove(this, EOPPOSITE_FEATURE_BASE - ModelPackage.MODEL__FMI, null, msgs);
			if (newFmi != null)
				msgs = ((InternalEObject)newFmi).eInverseAdd(this, EOPPOSITE_FEATURE_BASE - ModelPackage.MODEL__FMI, null, msgs);
			msgs = basicSetFmi(newFmi, msgs);
			if (msgs != null) msgs.dispatch();
		}
		else if (eNotificationRequired())
			eNotify(new ENotificationImpl(this, Notification.SET, ModelPackage.MODEL__FMI, newFmi, newFmi));
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public GeneralInfo getGeneralInfo() {
		return generalInfo;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public NotificationChain basicSetGeneralInfo(GeneralInfo newGeneralInfo, NotificationChain msgs) {
		GeneralInfo oldGeneralInfo = generalInfo;
		generalInfo = newGeneralInfo;
		if (eNotificationRequired()) {
			ENotificationImpl notification = new ENotificationImpl(this, Notification.SET, ModelPackage.MODEL__GENERAL_INFO, oldGeneralInfo, newGeneralInfo);
			if (msgs == null) msgs = notification; else msgs.add(notification);
		}
		return msgs;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public void setGeneralInfo(GeneralInfo newGeneralInfo) {
		if (newGeneralInfo != generalInfo) {
			NotificationChain msgs = null;
			if (generalInfo != null)
				msgs = ((InternalEObject)generalInfo).eInverseRemove(this, EOPPOSITE_FEATURE_BASE - ModelPackage.MODEL__GENERAL_INFO, null, msgs);
			if (newGeneralInfo != null)
				msgs = ((InternalEObject)newGeneralInfo).eInverseAdd(this, EOPPOSITE_FEATURE_BASE - ModelPackage.MODEL__GENERAL_INFO, null, msgs);
			msgs = basicSetGeneralInfo(newGeneralInfo, msgs);
			if (msgs != null) msgs.dispatch();
		}
		else if (eNotificationRequired())
			eNotify(new ENotificationImpl(this, Notification.SET, ModelPackage.MODEL__GENERAL_INFO, newGeneralInfo, newGeneralInfo));
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EList<ModeCondition> getGlobalModeConditions() {
		if (globalModeConditions == null) {
			globalModeConditions = new EObjectContainmentEList<ModeCondition>(ModeCondition.class, this, ModelPackage.MODEL__GLOBAL_MODE_CONDITIONS);
		}
		return globalModeConditions;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EList<ModeGroup> getGlobalModeGroups() {
		if (globalModeGroups == null) {
			globalModeGroups = new EObjectContainmentEList<ModeGroup>(ModeGroup.class, this, ModelPackage.MODEL__GLOBAL_MODE_GROUPS);
		}
		return globalModeGroups;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EList<Interconnect> getInterconnects() {
		if (interconnects == null) {
			interconnects = new EObjectContainmentEList<Interconnect>(Interconnect.class, this, ModelPackage.MODEL__INTERCONNECTS);
		}
		return interconnects;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EList<Memory> getMemories() {
		if (memories == null) {
			memories = new EObjectContainmentEList<Memory>(Memory.class, this, ModelPackage.MODEL__MEMORIES);
		}
		return memories;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public boolean isOmitCallNestingDiagram() {
		return omitCallNestingDiagram;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public void setOmitCallNestingDiagram(boolean newOmitCallNestingDiagram) {
		boolean oldOmitCallNestingDiagram = omitCallNestingDiagram;
		omitCallNestingDiagram = newOmitCallNestingDiagram;
		if (eNotificationRequired())
			eNotify(new ENotificationImpl(this, Notification.SET, ModelPackage.MODEL__OMIT_CALL_NESTING_DIAGRAM, oldOmitCallNestingDiagram, omitCallNestingDiagram));
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public boolean isOmitImplicitEventChains() {
		return omitImplicitEventChains;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public void setOmitImplicitEventChains(boolean newOmitImplicitEventChains) {
		boolean oldOmitImplicitEventChains = omitImplicitEventChains;
		omitImplicitEventChains = newOmitImplicitEventChains;
		if (eNotificationRequired())
			eNotify(new ENotificationImpl(this, Notification.SET, ModelPackage.MODEL__OMIT_IMPLICIT_EVENT_CHAINS, oldOmitImplicitEventChains, omitImplicitEventChains));
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public boolean isOmitStackDiagram() {
		return omitStackDiagram;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public void setOmitStackDiagram(boolean newOmitStackDiagram) {
		boolean oldOmitStackDiagram = omitStackDiagram;
		omitStackDiagram = newOmitStackDiagram;
		if (eNotificationRequired())
			eNotify(new ENotificationImpl(this, Notification.SET, ModelPackage.MODEL__OMIT_STACK_DIAGRAM, oldOmitStackDiagram, omitStackDiagram));
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EList<PortConnection> getPeripheralPortConnections() {
		if (peripheralPortConnections == null) {
			peripheralPortConnections = new EObjectContainmentEList<PortConnection>(PortConnection.class, this, ModelPackage.MODEL__PERIPHERAL_PORT_CONNECTIONS);
		}
		return peripheralPortConnections;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EList<Requirement> getRequirements() {
		if (requirements == null) {
			requirements = new EObjectContainmentEList<Requirement>(Requirement.class, this, ModelPackage.MODEL__REQUIREMENTS);
		}
		return requirements;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EList<StimulationScenario> getStimulationScenarios() {
		if (stimulationScenarios == null) {
			stimulationScenarios = new EObjectContainmentEList<StimulationScenario>(StimulationScenario.class, this, ModelPackage.MODEL__STIMULATION_SCENARIOS);
		}
		return stimulationScenarios;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public StimulationScenario getDefaultScenario() {
		if (defaultScenario != null && defaultScenario.eIsProxy()) {
			InternalEObject oldDefaultScenario = (InternalEObject)defaultScenario;
			defaultScenario = (StimulationScenario)eResolveProxy(oldDefaultScenario);
			if (defaultScenario != oldDefaultScenario) {
				if (eNotificationRequired())
					eNotify(new ENotificationImpl(this, Notification.RESOLVE, ModelPackage.MODEL__DEFAULT_SCENARIO, oldDefaultScenario, defaultScenario));
			}
		}
		return defaultScenario;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public StimulationScenario basicGetDefaultScenario() {
		return defaultScenario;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public void setDefaultScenario(StimulationScenario newDefaultScenario) {
		StimulationScenario oldDefaultScenario = defaultScenario;
		defaultScenario = newDefaultScenario;
		if (eNotificationRequired())
			eNotify(new ENotificationImpl(this, Notification.SET, ModelPackage.MODEL__DEFAULT_SCENARIO, oldDefaultScenario, defaultScenario));
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EList<com.inchron.realtime.root.model.System> getSystems() {
		if (systems == null) {
			systems = new EObjectContainmentEList<com.inchron.realtime.root.model.System>(com.inchron.realtime.root.model.System.class, this, ModelPackage.MODEL__SYSTEMS);
		}
		return systems;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EList<TraceEvent> getTraceEvents() {
		if (traceEvents == null) {
			traceEvents = new EObjectContainmentEList<TraceEvent>(TraceEvent.class, this, ModelPackage.MODEL__TRACE_EVENTS);
		}
		return traceEvents;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	@Override
	public NotificationChain eInverseRemove(InternalEObject otherEnd, int featureID, NotificationChain msgs) {
		switch (featureID) {
			case ModelPackage.MODEL__BUS_PERIPHERALS:
				return ((InternalEList<?>)getBusPeripherals()).basicRemove(otherEnd, msgs);
			case ModelPackage.MODEL__CLOCKS:
				return ((InternalEList<?>)getClocks()).basicRemove(otherEnd, msgs);
			case ModelPackage.MODEL__CPUS:
				return ((InternalEList<?>)getCpus()).basicRemove(otherEnd, msgs);
			case ModelPackage.MODEL__CONNECTIONS:
				return ((InternalEList<?>)getConnections()).basicRemove(otherEnd, msgs);
			case ModelPackage.MODEL__EVENT_CHAINS:
				return ((InternalEList<?>)getEventChains()).basicRemove(otherEnd, msgs);
			case ModelPackage.MODEL__EVENTS:
				return ((InternalEList<?>)getEvents()).basicRemove(otherEnd, msgs);
			case ModelPackage.MODEL__FMI:
				return basicSetFmi(null, msgs);
			case ModelPackage.MODEL__GENERAL_INFO:
				return basicSetGeneralInfo(null, msgs);
			case ModelPackage.MODEL__GLOBAL_MODE_CONDITIONS:
				return ((InternalEList<?>)getGlobalModeConditions()).basicRemove(otherEnd, msgs);
			case ModelPackage.MODEL__GLOBAL_MODE_GROUPS:
				return ((InternalEList<?>)getGlobalModeGroups()).basicRemove(otherEnd, msgs);
			case ModelPackage.MODEL__INTERCONNECTS:
				return ((InternalEList<?>)getInterconnects()).basicRemove(otherEnd, msgs);
			case ModelPackage.MODEL__MEMORIES:
				return ((InternalEList<?>)getMemories()).basicRemove(otherEnd, msgs);
			case ModelPackage.MODEL__PERIPHERAL_PORT_CONNECTIONS:
				return ((InternalEList<?>)getPeripheralPortConnections()).basicRemove(otherEnd, msgs);
			case ModelPackage.MODEL__REQUIREMENTS:
				return ((InternalEList<?>)getRequirements()).basicRemove(otherEnd, msgs);
			case ModelPackage.MODEL__STIMULATION_SCENARIOS:
				return ((InternalEList<?>)getStimulationScenarios()).basicRemove(otherEnd, msgs);
			case ModelPackage.MODEL__SYSTEMS:
				return ((InternalEList<?>)getSystems()).basicRemove(otherEnd, msgs);
			case ModelPackage.MODEL__TRACE_EVENTS:
				return ((InternalEList<?>)getTraceEvents()).basicRemove(otherEnd, msgs);
		}
		return super.eInverseRemove(otherEnd, featureID, msgs);
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	@Override
	public Object eGet(int featureID, boolean resolve, boolean coreType) {
		switch (featureID) {
			case ModelPackage.MODEL__BUS_PERIPHERALS:
				return getBusPeripherals();
			case ModelPackage.MODEL__CLOCKS:
				return getClocks();
			case ModelPackage.MODEL__CPUS:
				return getCpus();
			case ModelPackage.MODEL__CONNECTIONS:
				return getConnections();
			case ModelPackage.MODEL__EVENT_CHAINS:
				return getEventChains();
			case ModelPackage.MODEL__EVENTS:
				return getEvents();
			case ModelPackage.MODEL__FMI:
				return getFmi();
			case ModelPackage.MODEL__GENERAL_INFO:
				return getGeneralInfo();
			case ModelPackage.MODEL__GLOBAL_MODE_CONDITIONS:
				return getGlobalModeConditions();
			case ModelPackage.MODEL__GLOBAL_MODE_GROUPS:
				return getGlobalModeGroups();
			case ModelPackage.MODEL__INTERCONNECTS:
				return getInterconnects();
			case ModelPackage.MODEL__MEMORIES:
				return getMemories();
			case ModelPackage.MODEL__OMIT_CALL_NESTING_DIAGRAM:
				return isOmitCallNestingDiagram();
			case ModelPackage.MODEL__OMIT_IMPLICIT_EVENT_CHAINS:
				return isOmitImplicitEventChains();
			case ModelPackage.MODEL__OMIT_STACK_DIAGRAM:
				return isOmitStackDiagram();
			case ModelPackage.MODEL__PERIPHERAL_PORT_CONNECTIONS:
				return getPeripheralPortConnections();
			case ModelPackage.MODEL__REQUIREMENTS:
				return getRequirements();
			case ModelPackage.MODEL__STIMULATION_SCENARIOS:
				return getStimulationScenarios();
			case ModelPackage.MODEL__DEFAULT_SCENARIO:
				if (resolve) return getDefaultScenario();
				return basicGetDefaultScenario();
			case ModelPackage.MODEL__SYSTEMS:
				return getSystems();
			case ModelPackage.MODEL__TRACE_EVENTS:
				return getTraceEvents();
		}
		return super.eGet(featureID, resolve, coreType);
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	@SuppressWarnings("unchecked")
	@Override
	public void eSet(int featureID, Object newValue) {
		switch (featureID) {
			case ModelPackage.MODEL__BUS_PERIPHERALS:
				getBusPeripherals().clear();
				getBusPeripherals().addAll((Collection<? extends Bus>)newValue);
				return;
			case ModelPackage.MODEL__CLOCKS:
				getClocks().clear();
				getClocks().addAll((Collection<? extends Clock>)newValue);
				return;
			case ModelPackage.MODEL__CPUS:
				getCpus().clear();
				getCpus().addAll((Collection<? extends Cpu>)newValue);
				return;
			case ModelPackage.MODEL__CONNECTIONS:
				getConnections().clear();
				getConnections().addAll((Collection<? extends Connection>)newValue);
				return;
			case ModelPackage.MODEL__EVENT_CHAINS:
				getEventChains().clear();
				getEventChains().addAll((Collection<? extends EventChain>)newValue);
				return;
			case ModelPackage.MODEL__EVENTS:
				getEvents().clear();
				getEvents().addAll((Collection<? extends Event>)newValue);
				return;
			case ModelPackage.MODEL__FMI:
				setFmi((ModelDescription)newValue);
				return;
			case ModelPackage.MODEL__GENERAL_INFO:
				setGeneralInfo((GeneralInfo)newValue);
				return;
			case ModelPackage.MODEL__GLOBAL_MODE_CONDITIONS:
				getGlobalModeConditions().clear();
				getGlobalModeConditions().addAll((Collection<? extends ModeCondition>)newValue);
				return;
			case ModelPackage.MODEL__GLOBAL_MODE_GROUPS:
				getGlobalModeGroups().clear();
				getGlobalModeGroups().addAll((Collection<? extends ModeGroup>)newValue);
				return;
			case ModelPackage.MODEL__INTERCONNECTS:
				getInterconnects().clear();
				getInterconnects().addAll((Collection<? extends Interconnect>)newValue);
				return;
			case ModelPackage.MODEL__MEMORIES:
				getMemories().clear();
				getMemories().addAll((Collection<? extends Memory>)newValue);
				return;
			case ModelPackage.MODEL__OMIT_CALL_NESTING_DIAGRAM:
				setOmitCallNestingDiagram((Boolean)newValue);
				return;
			case ModelPackage.MODEL__OMIT_IMPLICIT_EVENT_CHAINS:
				setOmitImplicitEventChains((Boolean)newValue);
				return;
			case ModelPackage.MODEL__OMIT_STACK_DIAGRAM:
				setOmitStackDiagram((Boolean)newValue);
				return;
			case ModelPackage.MODEL__PERIPHERAL_PORT_CONNECTIONS:
				getPeripheralPortConnections().clear();
				getPeripheralPortConnections().addAll((Collection<? extends PortConnection>)newValue);
				return;
			case ModelPackage.MODEL__REQUIREMENTS:
				getRequirements().clear();
				getRequirements().addAll((Collection<? extends Requirement>)newValue);
				return;
			case ModelPackage.MODEL__STIMULATION_SCENARIOS:
				getStimulationScenarios().clear();
				getStimulationScenarios().addAll((Collection<? extends StimulationScenario>)newValue);
				return;
			case ModelPackage.MODEL__DEFAULT_SCENARIO:
				setDefaultScenario((StimulationScenario)newValue);
				return;
			case ModelPackage.MODEL__SYSTEMS:
				getSystems().clear();
				getSystems().addAll((Collection<? extends com.inchron.realtime.root.model.System>)newValue);
				return;
			case ModelPackage.MODEL__TRACE_EVENTS:
				getTraceEvents().clear();
				getTraceEvents().addAll((Collection<? extends TraceEvent>)newValue);
				return;
		}
		super.eSet(featureID, newValue);
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	@Override
	public void eUnset(int featureID) {
		switch (featureID) {
			case ModelPackage.MODEL__BUS_PERIPHERALS:
				getBusPeripherals().clear();
				return;
			case ModelPackage.MODEL__CLOCKS:
				getClocks().clear();
				return;
			case ModelPackage.MODEL__CPUS:
				getCpus().clear();
				return;
			case ModelPackage.MODEL__CONNECTIONS:
				getConnections().clear();
				return;
			case ModelPackage.MODEL__EVENT_CHAINS:
				getEventChains().clear();
				return;
			case ModelPackage.MODEL__EVENTS:
				getEvents().clear();
				return;
			case ModelPackage.MODEL__FMI:
				setFmi((ModelDescription)null);
				return;
			case ModelPackage.MODEL__GENERAL_INFO:
				setGeneralInfo((GeneralInfo)null);
				return;
			case ModelPackage.MODEL__GLOBAL_MODE_CONDITIONS:
				getGlobalModeConditions().clear();
				return;
			case ModelPackage.MODEL__GLOBAL_MODE_GROUPS:
				getGlobalModeGroups().clear();
				return;
			case ModelPackage.MODEL__INTERCONNECTS:
				getInterconnects().clear();
				return;
			case ModelPackage.MODEL__MEMORIES:
				getMemories().clear();
				return;
			case ModelPackage.MODEL__OMIT_CALL_NESTING_DIAGRAM:
				setOmitCallNestingDiagram(OMIT_CALL_NESTING_DIAGRAM_EDEFAULT);
				return;
			case ModelPackage.MODEL__OMIT_IMPLICIT_EVENT_CHAINS:
				setOmitImplicitEventChains(OMIT_IMPLICIT_EVENT_CHAINS_EDEFAULT);
				return;
			case ModelPackage.MODEL__OMIT_STACK_DIAGRAM:
				setOmitStackDiagram(OMIT_STACK_DIAGRAM_EDEFAULT);
				return;
			case ModelPackage.MODEL__PERIPHERAL_PORT_CONNECTIONS:
				getPeripheralPortConnections().clear();
				return;
			case ModelPackage.MODEL__REQUIREMENTS:
				getRequirements().clear();
				return;
			case ModelPackage.MODEL__STIMULATION_SCENARIOS:
				getStimulationScenarios().clear();
				return;
			case ModelPackage.MODEL__DEFAULT_SCENARIO:
				setDefaultScenario((StimulationScenario)null);
				return;
			case ModelPackage.MODEL__SYSTEMS:
				getSystems().clear();
				return;
			case ModelPackage.MODEL__TRACE_EVENTS:
				getTraceEvents().clear();
				return;
		}
		super.eUnset(featureID);
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	@Override
	public boolean eIsSet(int featureID) {
		switch (featureID) {
			case ModelPackage.MODEL__BUS_PERIPHERALS:
				return busPeripherals != null && !busPeripherals.isEmpty();
			case ModelPackage.MODEL__CLOCKS:
				return clocks != null && !clocks.isEmpty();
			case ModelPackage.MODEL__CPUS:
				return cpus != null && !cpus.isEmpty();
			case ModelPackage.MODEL__CONNECTIONS:
				return connections != null && !connections.isEmpty();
			case ModelPackage.MODEL__EVENT_CHAINS:
				return eventChains != null && !eventChains.isEmpty();
			case ModelPackage.MODEL__EVENTS:
				return events != null && !events.isEmpty();
			case ModelPackage.MODEL__FMI:
				return fmi != null;
			case ModelPackage.MODEL__GENERAL_INFO:
				return generalInfo != null;
			case ModelPackage.MODEL__GLOBAL_MODE_CONDITIONS:
				return globalModeConditions != null && !globalModeConditions.isEmpty();
			case ModelPackage.MODEL__GLOBAL_MODE_GROUPS:
				return globalModeGroups != null && !globalModeGroups.isEmpty();
			case ModelPackage.MODEL__INTERCONNECTS:
				return interconnects != null && !interconnects.isEmpty();
			case ModelPackage.MODEL__MEMORIES:
				return memories != null && !memories.isEmpty();
			case ModelPackage.MODEL__OMIT_CALL_NESTING_DIAGRAM:
				return omitCallNestingDiagram != OMIT_CALL_NESTING_DIAGRAM_EDEFAULT;
			case ModelPackage.MODEL__OMIT_IMPLICIT_EVENT_CHAINS:
				return omitImplicitEventChains != OMIT_IMPLICIT_EVENT_CHAINS_EDEFAULT;
			case ModelPackage.MODEL__OMIT_STACK_DIAGRAM:
				return omitStackDiagram != OMIT_STACK_DIAGRAM_EDEFAULT;
			case ModelPackage.MODEL__PERIPHERAL_PORT_CONNECTIONS:
				return peripheralPortConnections != null && !peripheralPortConnections.isEmpty();
			case ModelPackage.MODEL__REQUIREMENTS:
				return requirements != null && !requirements.isEmpty();
			case ModelPackage.MODEL__STIMULATION_SCENARIOS:
				return stimulationScenarios != null && !stimulationScenarios.isEmpty();
			case ModelPackage.MODEL__DEFAULT_SCENARIO:
				return defaultScenario != null;
			case ModelPackage.MODEL__SYSTEMS:
				return systems != null && !systems.isEmpty();
			case ModelPackage.MODEL__TRACE_EVENTS:
				return traceEvents != null && !traceEvents.isEmpty();
		}
		return super.eIsSet(featureID);
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	@Override
	public String toString() {
		if (eIsProxy()) return super.toString();

		StringBuffer result = new StringBuffer(super.toString());
		result.append(" (omitCallNestingDiagram: ");
		result.append(omitCallNestingDiagram);
		result.append(", omitImplicitEventChains: ");
		result.append(omitImplicitEventChains);
		result.append(", omitStackDiagram: ");
		result.append(omitStackDiagram);
		result.append(')');
		return result.toString();
	}

} //ModelImpl
