/**
 * Copyright (c) 2017-2018 INCHRON GmbH
 * 
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     INCHRON GmbH - Meta Model design and implementation
 */
package com.inchron.realtime.root.model.memory.util;

import com.inchron.realtime.root.Referrable;
import com.inchron.realtime.root.model.ClockUser;
import com.inchron.realtime.root.model.ModelObject;
import com.inchron.realtime.root.model.TraceObject;

import com.inchron.realtime.root.model.memory.*;

import org.eclipse.emf.common.notify.Adapter;
import org.eclipse.emf.common.notify.Notifier;

import org.eclipse.emf.common.notify.impl.AdapterFactoryImpl;

import org.eclipse.emf.ecore.EObject;

/**
 * <!-- begin-user-doc -->
 * The <b>Adapter Factory</b> for the model.
 * It provides an adapter <code>createXXX</code> method for each class of the model.
 * <!-- end-user-doc -->
 * @see com.inchron.realtime.root.model.memory.MemoryPackage
 * @generated
 */
public class MemoryAdapterFactory extends AdapterFactoryImpl {
	/**
	 * The cached model package.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	protected static MemoryPackage modelPackage;

	/**
	 * Creates an instance of the adapter factory.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public MemoryAdapterFactory() {
		if (modelPackage == null) {
			modelPackage = MemoryPackage.eINSTANCE;
		}
	}

	/**
	 * Returns whether this factory is applicable for the type of the object.
	 * <!-- begin-user-doc -->
	 * This implementation returns <code>true</code> if the object is either the model's package or is an instance object of the model.
	 * <!-- end-user-doc -->
	 * @return whether this factory is applicable for the type of the object.
	 * @generated
	 */
	@Override
	public boolean isFactoryForType(Object object) {
		if (object == modelPackage) {
			return true;
		}
		if (object instanceof EObject) {
			return ((EObject)object).eClass().getEPackage() == modelPackage;
		}
		return false;
	}

	/**
	 * The switch that delegates to the <code>createXXX</code> methods.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	protected MemorySwitch<Adapter> modelSwitch =
		new MemorySwitch<Adapter>() {
			@Override
			public Adapter caseResponderPort(ResponderPort object) {
				return createResponderPortAdapter();
			}
			@Override
			public Adapter caseInitiatorPort(InitiatorPort object) {
				return createInitiatorPortAdapter();
			}
			@Override
			public Adapter caseQosEntry(QosEntry object) {
				return createQosEntryAdapter();
			}
			@Override
			public Adapter caseInterconnect(Interconnect object) {
				return createInterconnectAdapter();
			}
			@Override
			public Adapter caseMemory(Memory object) {
				return createMemoryAdapter();
			}
			@Override
			public Adapter caseDataObject(DataObject object) {
				return createDataObjectAdapter();
			}
			@Override
			public Adapter caseDataAccess(DataAccess object) {
				return createDataAccessAdapter();
			}
			@Override
			public Adapter caseExplicitDataAccess(ExplicitDataAccess object) {
				return createExplicitDataAccessAdapter();
			}
			@Override
			public Adapter caseRateBasedDataAccess(RateBasedDataAccess object) {
				return createRateBasedDataAccessAdapter();
			}
			@Override
			public Adapter caseReferrable(Referrable object) {
				return createReferrableAdapter();
			}
			@Override
			public Adapter caseModelObject(ModelObject object) {
				return createModelObjectAdapter();
			}
			@Override
			public Adapter caseTraceObject(TraceObject object) {
				return createTraceObjectAdapter();
			}
			@Override
			public Adapter caseClockUser(ClockUser object) {
				return createClockUserAdapter();
			}
			@Override
			public Adapter defaultCase(EObject object) {
				return createEObjectAdapter();
			}
		};

	/**
	 * Creates an adapter for the <code>target</code>.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param target the object to adapt.
	 * @return the adapter for the <code>target</code>.
	 * @generated
	 */
	@Override
	public Adapter createAdapter(Notifier target) {
		return modelSwitch.doSwitch((EObject)target);
	}


	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.memory.ResponderPort <em>Responder Port</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.memory.ResponderPort
	 * @generated
	 */
	public Adapter createResponderPortAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.memory.InitiatorPort <em>Initiator Port</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.memory.InitiatorPort
	 * @generated
	 */
	public Adapter createInitiatorPortAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.memory.QosEntry <em>Qos Entry</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.memory.QosEntry
	 * @generated
	 */
	public Adapter createQosEntryAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.memory.Interconnect <em>Interconnect</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.memory.Interconnect
	 * @generated
	 */
	public Adapter createInterconnectAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.memory.Memory <em>Memory</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.memory.Memory
	 * @generated
	 */
	public Adapter createMemoryAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.memory.DataObject <em>Data Object</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.memory.DataObject
	 * @generated
	 */
	public Adapter createDataObjectAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.memory.DataAccess <em>Data Access</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.memory.DataAccess
	 * @generated
	 */
	public Adapter createDataAccessAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.memory.ExplicitDataAccess <em>Explicit Data Access</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.memory.ExplicitDataAccess
	 * @generated
	 */
	public Adapter createExplicitDataAccessAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.memory.RateBasedDataAccess <em>Rate Based Data Access</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.memory.RateBasedDataAccess
	 * @generated
	 */
	public Adapter createRateBasedDataAccessAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.Referrable <em>Referrable</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.Referrable
	 * @generated
	 */
	public Adapter createReferrableAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.ModelObject <em>Object</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.ModelObject
	 * @generated
	 */
	public Adapter createModelObjectAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.TraceObject <em>Trace Object</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.TraceObject
	 * @generated
	 */
	public Adapter createTraceObjectAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.ClockUser <em>Clock User</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.ClockUser
	 * @generated
	 */
	public Adapter createClockUserAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for the default case.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @generated
	 */
	public Adapter createEObjectAdapter() {
		return null;
	}

} //MemoryAdapterFactory
