/**
 * Copyright (c) 2017-2018 INCHRON GmbH
 * 
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     INCHRON GmbH - Meta Model design and implementation
 */
package com.inchron.realtime.root.model.peripheral.util;

import com.inchron.realtime.root.Referrable;

import com.inchron.realtime.root.model.LoadResource;
import com.inchron.realtime.root.model.ModelObject;
import com.inchron.realtime.root.model.TraceObject;

import com.inchron.realtime.root.model.peripheral.*;

import org.eclipse.emf.common.notify.Adapter;
import org.eclipse.emf.common.notify.Notifier;

import org.eclipse.emf.common.notify.impl.AdapterFactoryImpl;

import org.eclipse.emf.ecore.EObject;

/**
 * <!-- begin-user-doc -->
 * The <b>Adapter Factory</b> for the model.
 * It provides an adapter <code>createXXX</code> method for each class of the model.
 * <!-- end-user-doc -->
 * @see com.inchron.realtime.root.model.peripheral.PeripheralPackage
 * @generated
 */
public class PeripheralAdapterFactory extends AdapterFactoryImpl {
	/**
	 * The cached model package.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	protected static PeripheralPackage modelPackage;

	/**
	 * Creates an instance of the adapter factory.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public PeripheralAdapterFactory() {
		if (modelPackage == null) {
			modelPackage = PeripheralPackage.eINSTANCE;
		}
	}

	/**
	 * Returns whether this factory is applicable for the type of the object.
	 * <!-- begin-user-doc -->
	 * This implementation returns <code>true</code> if the object is either the model's package or is an instance object of the model.
	 * <!-- end-user-doc -->
	 * @return whether this factory is applicable for the type of the object.
	 * @generated
	 */
	@Override
	public boolean isFactoryForType(Object object) {
		if (object == modelPackage) {
			return true;
		}
		if (object instanceof EObject) {
			return ((EObject)object).eClass().getEPackage() == modelPackage;
		}
		return false;
	}

	/**
	 * The switch that delegates to the <code>createXXX</code> methods.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	protected PeripheralSwitch<Adapter> modelSwitch =
		new PeripheralSwitch<Adapter>() {
			@Override
			public Adapter caseAbstractPort(AbstractPort object) {
				return createAbstractPortAdapter();
			}
			@Override
			public Adapter caseBusMasterPort(BusMasterPort object) {
				return createBusMasterPortAdapter();
			}
			@Override
			public Adapter caseBusSlavePort(BusSlavePort object) {
				return createBusSlavePortAdapter();
			}
			@Override
			public Adapter caseInterruptPort(InterruptPort object) {
				return createInterruptPortAdapter();
			}
			@Override
			public Adapter caseInputPort(InputPort object) {
				return createInputPortAdapter();
			}
			@Override
			public Adapter caseOutputPort(OutputPort object) {
				return createOutputPortAdapter();
			}
			@Override
			public Adapter caseBiDirPort(BiDirPort object) {
				return createBiDirPortAdapter();
			}
			@Override
			public Adapter casePortConnection(PortConnection object) {
				return createPortConnectionAdapter();
			}
			@Override
			public Adapter caseAbstractPeripheral(AbstractPeripheral object) {
				return createAbstractPeripheralAdapter();
			}
			@Override
			public Adapter casePeripheral(Peripheral object) {
				return createPeripheralAdapter();
			}
			@Override
			public Adapter caseBus(Bus object) {
				return createBusAdapter();
			}
			@Override
			public Adapter caseAbstractEthernet(AbstractEthernet object) {
				return createAbstractEthernetAdapter();
			}
			@Override
			public Adapter caseAFDXPort(AFDXPort object) {
				return createAFDXPortAdapter();
			}
			@Override
			public Adapter caseAFDXEthernet(AFDXEthernet object) {
				return createAFDXEthernetAdapter();
			}
			@Override
			public Adapter caseAS5643(AS5643 object) {
				return createAS5643Adapter();
			}
			@Override
			public Adapter caseAS5643Bus(AS5643Bus object) {
				return createAS5643BusAdapter();
			}
			@Override
			public Adapter caseCAN(CAN object) {
				return createCANAdapter();
			}
			@Override
			public Adapter caseCANBus(CANBus object) {
				return createCANBusAdapter();
			}
			@Override
			public Adapter caseConsole(Console object) {
				return createConsoleAdapter();
			}
			@Override
			public Adapter caseEthernet(Ethernet object) {
				return createEthernetAdapter();
			}
			@Override
			public Adapter caseEthernetSwitch(EthernetSwitch object) {
				return createEthernetSwitchAdapter();
			}
			@Override
			public Adapter caseFlexRay(FlexRay object) {
				return createFlexRayAdapter();
			}
			@Override
			public Adapter caseFlexRayBus(FlexRayBus object) {
				return createFlexRayBusAdapter();
			}
			@Override
			public Adapter caseGenericIO(GenericIO object) {
				return createGenericIOAdapter();
			}
			@Override
			public Adapter caseIRQ(IRQ object) {
				return createIRQAdapter();
			}
			@Override
			public Adapter caseLIN(LIN object) {
				return createLINAdapter();
			}
			@Override
			public Adapter caseRestBus(RestBus object) {
				return createRestBusAdapter();
			}
			@Override
			public Adapter caseRestBusCAN(RestBusCAN object) {
				return createRestBusCANAdapter();
			}
			@Override
			public Adapter caseRestBusFlexRay(RestBusFlexRay object) {
				return createRestBusFlexRayAdapter();
			}
			@Override
			public Adapter caseTimer(Timer object) {
				return createTimerAdapter();
			}
			@Override
			public Adapter caseReferrable(Referrable object) {
				return createReferrableAdapter();
			}
			@Override
			public Adapter caseModelObject(ModelObject object) {
				return createModelObjectAdapter();
			}
			@Override
			public Adapter caseTraceObject(TraceObject object) {
				return createTraceObjectAdapter();
			}
			@Override
			public Adapter caseLoadResource(LoadResource object) {
				return createLoadResourceAdapter();
			}
			@Override
			public Adapter defaultCase(EObject object) {
				return createEObjectAdapter();
			}
		};

	/**
	 * Creates an adapter for the <code>target</code>.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param target the object to adapt.
	 * @return the adapter for the <code>target</code>.
	 * @generated
	 */
	@Override
	public Adapter createAdapter(Notifier target) {
		return modelSwitch.doSwitch((EObject)target);
	}


	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.AbstractPort <em>Abstract Port</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.AbstractPort
	 * @generated
	 */
	public Adapter createAbstractPortAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.BusMasterPort <em>Bus Master Port</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.BusMasterPort
	 * @generated
	 */
	public Adapter createBusMasterPortAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.BusSlavePort <em>Bus Slave Port</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.BusSlavePort
	 * @generated
	 */
	public Adapter createBusSlavePortAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.InterruptPort <em>Interrupt Port</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.InterruptPort
	 * @generated
	 */
	public Adapter createInterruptPortAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.InputPort <em>Input Port</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.InputPort
	 * @generated
	 */
	public Adapter createInputPortAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.OutputPort <em>Output Port</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.OutputPort
	 * @generated
	 */
	public Adapter createOutputPortAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.BiDirPort <em>Bi Dir Port</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.BiDirPort
	 * @generated
	 */
	public Adapter createBiDirPortAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.PortConnection <em>Port Connection</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.PortConnection
	 * @generated
	 */
	public Adapter createPortConnectionAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.AbstractPeripheral <em>Abstract Peripheral</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.AbstractPeripheral
	 * @generated
	 */
	public Adapter createAbstractPeripheralAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.Peripheral <em>Peripheral</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.Peripheral
	 * @generated
	 */
	public Adapter createPeripheralAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.Bus <em>Bus</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.Bus
	 * @generated
	 */
	public Adapter createBusAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.AbstractEthernet <em>Abstract Ethernet</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.AbstractEthernet
	 * @generated
	 */
	public Adapter createAbstractEthernetAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.AFDXPort <em>AFDX Port</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.AFDXPort
	 * @generated
	 */
	public Adapter createAFDXPortAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.AFDXEthernet <em>AFDX Ethernet</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.AFDXEthernet
	 * @generated
	 */
	public Adapter createAFDXEthernetAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.AS5643 <em>AS5643</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.AS5643
	 * @generated
	 */
	public Adapter createAS5643Adapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.AS5643Bus <em>AS5643 Bus</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.AS5643Bus
	 * @generated
	 */
	public Adapter createAS5643BusAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.CAN <em>CAN</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.CAN
	 * @generated
	 */
	public Adapter createCANAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.CANBus <em>CAN Bus</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.CANBus
	 * @generated
	 */
	public Adapter createCANBusAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.Console <em>Console</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.Console
	 * @generated
	 */
	public Adapter createConsoleAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.Ethernet <em>Ethernet</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.Ethernet
	 * @generated
	 */
	public Adapter createEthernetAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.EthernetSwitch <em>Ethernet Switch</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.EthernetSwitch
	 * @generated
	 */
	public Adapter createEthernetSwitchAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.FlexRay <em>Flex Ray</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.FlexRay
	 * @generated
	 */
	public Adapter createFlexRayAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.FlexRayBus <em>Flex Ray Bus</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.FlexRayBus
	 * @generated
	 */
	public Adapter createFlexRayBusAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.GenericIO <em>Generic IO</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.GenericIO
	 * @generated
	 */
	public Adapter createGenericIOAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.IRQ <em>IRQ</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.IRQ
	 * @generated
	 */
	public Adapter createIRQAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.LIN <em>LIN</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.LIN
	 * @generated
	 */
	public Adapter createLINAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.RestBus <em>Rest Bus</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.RestBus
	 * @generated
	 */
	public Adapter createRestBusAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.RestBusCAN <em>Rest Bus CAN</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.RestBusCAN
	 * @generated
	 */
	public Adapter createRestBusCANAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.RestBusFlexRay <em>Rest Bus Flex Ray</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.RestBusFlexRay
	 * @generated
	 */
	public Adapter createRestBusFlexRayAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.peripheral.Timer <em>Timer</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.peripheral.Timer
	 * @generated
	 */
	public Adapter createTimerAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.Referrable <em>Referrable</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.Referrable
	 * @generated
	 */
	public Adapter createReferrableAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.ModelObject <em>Object</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.ModelObject
	 * @generated
	 */
	public Adapter createModelObjectAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.TraceObject <em>Trace Object</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.TraceObject
	 * @generated
	 */
	public Adapter createTraceObjectAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.LoadResource <em>Load Resource</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.LoadResource
	 * @generated
	 */
	public Adapter createLoadResourceAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for the default case.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @generated
	 */
	public Adapter createEObjectAdapter() {
		return null;
	}

} //PeripheralAdapterFactory
