/**
 * Copyright (c) 2017-2018 INCHRON GmbH
 * 
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     INCHRON GmbH - Meta Model design and implementation
 */
package com.inchron.realtime.root.model.stimulation.util;

import com.inchron.realtime.root.Referrable;

import com.inchron.realtime.root.model.ClockUser;
import com.inchron.realtime.root.model.ModelObject;

import com.inchron.realtime.root.model.stimulation.*;

import org.eclipse.emf.common.notify.Adapter;
import org.eclipse.emf.common.notify.Notifier;

import org.eclipse.emf.common.notify.impl.AdapterFactoryImpl;

import org.eclipse.emf.ecore.EObject;

/**
 * <!-- begin-user-doc -->
 * The <b>Adapter Factory</b> for the model.
 * It provides an adapter <code>createXXX</code> method for each class of the model.
 * <!-- end-user-doc -->
 * @see com.inchron.realtime.root.model.stimulation.StimulationPackage
 * @generated
 */
public class StimulationAdapterFactory extends AdapterFactoryImpl {
	/**
	 * The cached model package.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	protected static StimulationPackage modelPackage;

	/**
	 * Creates an instance of the adapter factory.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public StimulationAdapterFactory() {
		if (modelPackage == null) {
			modelPackage = StimulationPackage.eINSTANCE;
		}
	}

	/**
	 * Returns whether this factory is applicable for the type of the object.
	 * <!-- begin-user-doc -->
	 * This implementation returns <code>true</code> if the object is either the model's package or is an instance object of the model.
	 * <!-- end-user-doc -->
	 * @return whether this factory is applicable for the type of the object.
	 * @generated
	 */
	@Override
	public boolean isFactoryForType(Object object) {
		if (object == modelPackage) {
			return true;
		}
		if (object instanceof EObject) {
			return ((EObject)object).eClass().getEPackage() == modelPackage;
		}
		return false;
	}

	/**
	 * The switch that delegates to the <code>createXXX</code> methods.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	protected StimulationSwitch<Adapter> modelSwitch =
		new StimulationSwitch<Adapter>() {
			@Override
			public Adapter caseBurstPattern(BurstPattern object) {
				return createBurstPatternAdapter();
			}
			@Override
			public Adapter caseBurstPatternGenerator(BurstPatternGenerator object) {
				return createBurstPatternGeneratorAdapter();
			}
			@Override
			public Adapter caseCSVBasedGenerator(CSVBasedGenerator object) {
				return createCSVBasedGeneratorAdapter();
			}
			@Override
			public Adapter caseCompositeScenario(CompositeScenario object) {
				return createCompositeScenarioAdapter();
			}
			@Override
			public Adapter caseDisturbanceFilter(DisturbanceFilter object) {
				return createDisturbanceFilterAdapter();
			}
			@Override
			public Adapter caseDriftFilter(DriftFilter object) {
				return createDriftFilterAdapter();
			}
			@Override
			public Adapter caseEliminationFilter(EliminationFilter object) {
				return createEliminationFilterAdapter();
			}
			@Override
			public Adapter caseInducedGenerator(InducedGenerator object) {
				return createInducedGeneratorAdapter();
			}
			@Override
			public Adapter caseInducedListBasedGenerator(InducedListBasedGenerator object) {
				return createInducedListBasedGeneratorAdapter();
			}
			@Override
			public Adapter caseListBasedGenerator(ListBasedGenerator object) {
				return createListBasedGeneratorAdapter();
			}
			@Override
			public Adapter caseRandomStimuliGenerator(RandomStimuliGenerator object) {
				return createRandomStimuliGeneratorAdapter();
			}
			@Override
			public Adapter caseStimulationFilter(StimulationFilter object) {
				return createStimulationFilterAdapter();
			}
			@Override
			public Adapter caseStimulationScenario(StimulationScenario object) {
				return createStimulationScenarioAdapter();
			}
			@Override
			public Adapter caseStimuliGenerator(StimuliGenerator object) {
				return createStimuliGeneratorAdapter();
			}
			@Override
			public Adapter caseReferrable(Referrable object) {
				return createReferrableAdapter();
			}
			@Override
			public Adapter caseModelObject(ModelObject object) {
				return createModelObjectAdapter();
			}
			@Override
			public Adapter caseClockUser(ClockUser object) {
				return createClockUserAdapter();
			}
			@Override
			public Adapter defaultCase(EObject object) {
				return createEObjectAdapter();
			}
		};

	/**
	 * Creates an adapter for the <code>target</code>.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param target the object to adapt.
	 * @return the adapter for the <code>target</code>.
	 * @generated
	 */
	@Override
	public Adapter createAdapter(Notifier target) {
		return modelSwitch.doSwitch((EObject)target);
	}


	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.stimulation.BurstPattern <em>Burst Pattern</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.stimulation.BurstPattern
	 * @generated
	 */
	public Adapter createBurstPatternAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.stimulation.BurstPatternGenerator <em>Burst Pattern Generator</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.stimulation.BurstPatternGenerator
	 * @generated
	 */
	public Adapter createBurstPatternGeneratorAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.stimulation.CSVBasedGenerator <em>CSV Based Generator</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.stimulation.CSVBasedGenerator
	 * @generated
	 */
	public Adapter createCSVBasedGeneratorAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.stimulation.CompositeScenario <em>Composite Scenario</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.stimulation.CompositeScenario
	 * @generated
	 */
	public Adapter createCompositeScenarioAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.stimulation.DisturbanceFilter <em>Disturbance Filter</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.stimulation.DisturbanceFilter
	 * @generated
	 */
	public Adapter createDisturbanceFilterAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.stimulation.DriftFilter <em>Drift Filter</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.stimulation.DriftFilter
	 * @generated
	 */
	public Adapter createDriftFilterAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.stimulation.EliminationFilter <em>Elimination Filter</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.stimulation.EliminationFilter
	 * @generated
	 */
	public Adapter createEliminationFilterAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.stimulation.InducedGenerator <em>Induced Generator</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.stimulation.InducedGenerator
	 * @generated
	 */
	public Adapter createInducedGeneratorAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.stimulation.InducedListBasedGenerator <em>Induced List Based Generator</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.stimulation.InducedListBasedGenerator
	 * @generated
	 */
	public Adapter createInducedListBasedGeneratorAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.stimulation.ListBasedGenerator <em>List Based Generator</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.stimulation.ListBasedGenerator
	 * @generated
	 */
	public Adapter createListBasedGeneratorAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.stimulation.RandomStimuliGenerator <em>Random Stimuli Generator</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.stimulation.RandomStimuliGenerator
	 * @generated
	 */
	public Adapter createRandomStimuliGeneratorAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.stimulation.StimulationFilter <em>Filter</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.stimulation.StimulationFilter
	 * @generated
	 */
	public Adapter createStimulationFilterAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.stimulation.StimulationScenario <em>Scenario</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.stimulation.StimulationScenario
	 * @generated
	 */
	public Adapter createStimulationScenarioAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.stimulation.StimuliGenerator <em>Stimuli Generator</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.stimulation.StimuliGenerator
	 * @generated
	 */
	public Adapter createStimuliGeneratorAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.Referrable <em>Referrable</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.Referrable
	 * @generated
	 */
	public Adapter createReferrableAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.ModelObject <em>Object</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.ModelObject
	 * @generated
	 */
	public Adapter createModelObjectAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link com.inchron.realtime.root.model.ClockUser <em>Clock User</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see com.inchron.realtime.root.model.ClockUser
	 * @generated
	 */
	public Adapter createClockUserAdapter() {
		return null;
	}

	/**
	 * Creates a new adapter for the default case.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @generated
	 */
	public Adapter createEObjectAdapter() {
		return null;
	}

} //StimulationAdapterFactory
