 /**
 ********************************************************************************
 * Copyright (c) 2017 - 2018 Robert Bosch GmbH.
 * 
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Robert Bosch GmbH - initial API and implementation
 ********************************************************************************
 */
package org.eclipse.app4mc.emfutils.content.extractor.builders;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.emf.common.util.BasicEList;
import org.eclipse.emf.common.util.BasicEMap;
import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.common.util.EMap;
import org.eclipse.emf.ecore.EAttribute;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EClassifier;
import org.eclipse.emf.ecore.EDataType;
import org.eclipse.emf.ecore.EEnum;
import org.eclipse.emf.ecore.EEnumLiteral;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.emf.ecore.EReference;
import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecore.resource.ResourceSet;
import org.eclipse.emf.ecore.util.EcoreUtil;

public class EClassContentsFromReferenceBufferBuilder {

	private EMap<String, Object> id2ObjectsMap;

	private final EList<EClass> addedEClassifiers = new BasicEList<EClass>();

	public EMap<String, Object> getId2ObjectsMap() {
		return this.id2ObjectsMap;
	}


	public void setId2ObjectsMap(final EMap<String, Object> id2ObjectsMap) {
		this.id2ObjectsMap = id2ObjectsMap;
	}


	public StringBuffer buildBuffer(final EClass selectedObjClass) {

		this.addedEClassifiers.clear();

		this.id2ObjectsMap = new BasicEMap<String, Object>();

		final StringBuffer plantumlBuffer = new StringBuffer();


		plantumlBuffer.append("@startuml");
		plantumlBuffer.append(System.getProperty("line.separator"));


		fillPlantUMLSkinParams(plantumlBuffer);

		if (selectedObjClass.getESuperTypes().size() > 0) {

			populateHeirarchy(plantumlBuffer, selectedObjClass);

		}
		else {

			/*- no references for this EClass are found */
			createClass(plantumlBuffer, selectedObjClass, "SelectedElement", 1);

		}

		populateSubClassInfo(selectedObjClass, plantumlBuffer);


		plantumlBuffer.append(System.getProperty("line.separator"));
		plantumlBuffer.append("@enduml");

		return plantumlBuffer;

	}

	private void populateSubClassInfo(final EClass selectedObjClass, final StringBuffer plantumlBuffer) {
		for (final EClass subClass : getSubClasses(selectedObjClass)) {


			createClass(plantumlBuffer, subClass, "SelectedElement", 1);

			plantumlBuffer.append(System.getProperty("line.separator"));

			plantumlBuffer.append(selectedObjClass.getName() + " <|-- " + subClass.getName());

			plantumlBuffer.append(System.getProperty("line.separator"));

		}
	}


	private void fillPlantUMLSkinParams(final StringBuffer plantumlBuffer) {
		plantumlBuffer.append(System.getProperty("line.separator"));
		plantumlBuffer.append("skinparam class {");
		plantumlBuffer.append(System.getProperty("line.separator"));
		plantumlBuffer.append("BackgroundColor PaleGreen");
		plantumlBuffer.append(System.getProperty("line.separator"));
		plantumlBuffer.append("ArrowColor SeaGreen");
		plantumlBuffer.append(System.getProperty("line.separator"));
		plantumlBuffer.append("BorderColor SpringGreen");
		plantumlBuffer.append(System.getProperty("line.separator"));
		plantumlBuffer.append("BackgroundColor<<H>> Wheat");
		plantumlBuffer.append(System.getProperty("line.separator"));
		plantumlBuffer.append("BorderColor<<H>> Tomato");
		plantumlBuffer.append(System.getProperty("line.separator"));

		plantumlBuffer.append("BackgroundColor<<SelectedElement>> DarkOrange ");
		plantumlBuffer.append(System.getProperty("line.separator"));

		plantumlBuffer.append("BorderColor<<SelectedElement>> Tomato");
		plantumlBuffer.append(System.getProperty("line.separator"));

		plantumlBuffer.append("}");
		plantumlBuffer.append(System.getProperty("line.separator"));


		plantumlBuffer.append("skinparam stereotypeCBackgroundColor YellowGreen");
		plantumlBuffer.append(System.getProperty("line.separator"));

		plantumlBuffer.append("skinparam stereotypeCBackgroundColor <<H>> DimGray");
		plantumlBuffer.append(System.getProperty("line.separator"));


	}

	private void populateHeirarchy(final StringBuffer plantumlBuffer, final EClass selectedObjClass) {

		createClass(plantumlBuffer, selectedObjClass, "H", 1);

	}


	private void createEEnum(final StringBuffer plantumlBuffer, final EEnum eClassifier, final int level) {

		plantumlBuffer.append("enum \"" + eClassifier.getName() + "\"");
		plantumlBuffer.append("{");
		plantumlBuffer.append(System.getProperty("line.separator"));

		final EList<EEnumLiteral> eTypeParameters = eClassifier.getELiterals();

		for (final EEnumLiteral eTypeParameter : eTypeParameters) {

			plantumlBuffer.append(System.getProperty("line.separator"));
			plantumlBuffer.append(eTypeParameter.getName());


		}
		plantumlBuffer.append(System.getProperty("line.separator"));
		plantumlBuffer.append("}");


	}

	private void createEDataType(final StringBuffer plantumlBuffer, final EDataType eClassifier, final int level) {

	}


	private void createClass(final StringBuffer plantumlBuffer, final EClass eClass, final String stereoType,
			final int level) {

		if (!this.addedEClassifiers.contains(eClass)) {

			this.addedEClassifiers.add(eClass);

			/*- =================================== Start of Class Object =================================== */

			final String uuid = EcoreUtil.generateUUID();


			if (eClass.isAbstract() && eClass.isInterface()) {
				plantumlBuffer.append("interface \"" + eClass.getName() + "\"");

			}
			else if (eClass.isAbstract()) {
				plantumlBuffer.append("abstract \"" + eClass.getName() + "\"");

			}
			else if (eClass.isInterface()) {

				plantumlBuffer.append("interface \"" + eClass.getName() + "\"");
			}
			else {
				plantumlBuffer.append("class \"" + eClass.getName() + "\"");

			}

			if (stereoType != null) {
				plantumlBuffer.append("<<" + stereoType + ">>");
			}

			plantumlBuffer.append("    [[" + uuid + "]] ");

			this.id2ObjectsMap.put(uuid, eClass);


			/*- listing attributes beloning to the specific EMF element */

			final EList<EAttribute> eAttributes = eClass.getEAllAttributes();
			final EList<EStructuralFeature> eStructuralFeatures = eClass.getEAllStructuralFeatures();

			plantumlBuffer.append("{");

			final List<EAttribute> referredEnums = new ArrayList<EAttribute>();

			if (eAttributes.size() > 0) {


				plantumlBuffer.append(System.getProperty("line.separator"));

				final List<EAttribute> processedAttributes = new ArrayList<EAttribute>();

				for (final EAttribute eAttribute : eAttributes) {

					if (!processedAttributes.contains(eAttribute)) {

						if (eAttribute.getEAttributeType() instanceof EEnum) {
							referredEnums.add(eAttribute);
						}

						processedAttributes.add(eAttribute);

						plantumlBuffer.append(System.getProperty("line.separator"));

						final String lowerBound = eAttribute.getLowerBound() == -1 ? "*"
								: eAttribute.getLowerBound() + "";

						final String upperBound = eAttribute.getUpperBound() == -1 ? "*"
								: eAttribute.getUpperBound() + "";

						plantumlBuffer.append(eAttribute.getEType().getName() + " " + eAttribute.getName() + " ["
								+ lowerBound + ":" + upperBound + "]");

						plantumlBuffer.append(System.getProperty("line.separator"));
					}


				}
				plantumlBuffer.append(System.getProperty("line.separator"));


			}
			plantumlBuffer.append(System.getProperty("line.separator"));


			/*- listing EStructuralFeatures beloning to the specific EMF element */

			final List<EStructuralFeature> processedFeatures = new ArrayList<EStructuralFeature>();

			final List<EStructuralFeature> referredEStrcuturalFeatures = new ArrayList<EStructuralFeature>();

			for (final EStructuralFeature eStructuralFeature : eStructuralFeatures) {

				plantumlBuffer.append(System.getProperty("line.separator"));

				if (!processedFeatures.contains(eStructuralFeature) && (eStructuralFeature instanceof EReference)) {

					processedFeatures.add(eStructuralFeature);

					referredEStrcuturalFeatures.add(eStructuralFeature);

					final String lowerBound = eStructuralFeature.getLowerBound() == -1 ? "*"
							: eStructuralFeature.getLowerBound() + "";

					final String upperBound = eStructuralFeature.getUpperBound() == -1 ? "*"
							: eStructuralFeature.getUpperBound() + "";

					plantumlBuffer.append(eStructuralFeature.getEType().getName() + " " + eStructuralFeature.getName()
							+ " [" + lowerBound + ":" + upperBound + "]");

					plantumlBuffer.append(System.getProperty("line.separator"));

				}
			}

			plantumlBuffer.append("}");

			/*- =================================== End of Class Object =================================== */

			plantumlBuffer.append(System.getProperty("line.separator"));

			for (final EStructuralFeature eStructuralFeature : referredEStrcuturalFeatures) {

				createEClassifier(plantumlBuffer, eStructuralFeature.getEType(), level + 1);

				plantumlBuffer.append(System.getProperty("line.separator"));

				final String relation = ((EReference) eStructuralFeature).isContainment() ? " *-- " : "--> ";


				final String lowerBound = eStructuralFeature.getLowerBound() == -1 ? "*"
						: eStructuralFeature.getLowerBound() + "";

				final String upperBound = eStructuralFeature.getUpperBound() == -1 ? "*"
						: eStructuralFeature.getUpperBound() + "";


				plantumlBuffer.append(eClass.getName() + relation + eStructuralFeature.getEType().getName() + " : "
						+ eStructuralFeature.getName() + " [" + lowerBound + ":" + upperBound + "]");

				plantumlBuffer.append(System.getProperty("line.separator"));

			}


			plantumlBuffer.append(System.getProperty("line.separator"));

			for (final EAttribute eAttribute : referredEnums) {

				createEClassifier(plantumlBuffer, eAttribute.getEType(), level + 1);

				plantumlBuffer.append(System.getProperty("line.separator"));


				final String lowerBound = eAttribute.getLowerBound() == -1 ? "*" : eAttribute.getLowerBound() + "";

				final String upperBound = eAttribute.getUpperBound() == -1 ? "*" : eAttribute.getUpperBound() + "";


				plantumlBuffer.append(eClass.getName() + " *-- " + eAttribute.getEType().getName() + " : "
						+ eAttribute.getName() + " [" + lowerBound + ":" + upperBound + "]");

				plantumlBuffer.append(System.getProperty("line.separator"));

			}


			plantumlBuffer.append(System.getProperty("line.separator"));


		}

	}


	private void createEClassifier(final StringBuffer plantumlBuffer, final EClassifier eClassifier, final int level) {

		if (level > 2) {
			return;
		}
		if (eClassifier instanceof EClass) {
			createClass(plantumlBuffer, (EClass) eClassifier, null, level);
		}
		else if (eClassifier instanceof EEnum) {
			createEEnum(plantumlBuffer, (EEnum) eClassifier, level);
		}
		else if (eClassifier instanceof EDataType) {
			createEDataType(plantumlBuffer, (EDataType) eClassifier, level);
		}
	}

	private List<EClass> getSubClasses(final EClass selectedObjClass) {

		final List<EClass> allSubClasses = new ArrayList<EClass>();

		final ResourceSet resourceSet = selectedObjClass.eResource().getResourceSet();

		if (resourceSet != null) {

			// With this approach check is made to find the Sub-Classes for the supplied EClass in all the packages
			// belonging to the resourceset

			final EList<Resource> resources = resourceSet.getResources();

			for (final Resource resource : resources) {

				final EList<EObject> contents = resource.getContents();

				if (contents.size() > 0) {
					final EObject eObject = contents.get(0);

					if (eObject instanceof EPackage) {
						allSubClasses.addAll(getSubClasses(selectedObjClass, (EPackage) eObject));
					}
				}

			}
		}
		else {

			final EPackage ePackage = selectedObjClass.getEPackage();
			return getSubClasses(selectedObjClass, ePackage);
		}

		return allSubClasses;

	}

	private List<EClass> getSubClasses(final EClass selectedObjClass, final EPackage ePackage) {
		final List<EClass> allSubClasses = new ArrayList<EClass>();

		final EList<EClassifier> eClassifiers = ePackage.getEClassifiers();

		for (final EClassifier eClassifier : eClassifiers) {

			if (eClassifier instanceof EClass) {

				if (!(selectedObjClass == eClassifier) && selectedObjClass.isSuperTypeOf((EClass) eClassifier)) {
					allSubClasses.add((EClass) eClassifier);
				}


			}
		}
		return allSubClasses;
	}


}
